@@ -254,12 +254,21 @@ class Identifier {
 	 * @return bool
 	 **/
 	public function verifier_token() {
-		if (!$this->token) {
+		if (!$this->verifier_un_token($this->token)) {
+			return false;
+		}
+		[$champ, $time, $cle] = explode(':', $this->token);
+		$this->champ = $champ;
+		return true;
+	}
+
+	public function verifier_un_token(string $token): bool {
+		if (!$token) {
 			static::debug('Aucun token');
 			return false;
 		}
 
-		$_token = explode(':', $this->token);
+		$_token = explode(':', $token);
 
 		if (count($_token) != 3) {
 			static::debug('Token mal formé');
@@ -270,7 +279,6 @@ class Identifier {
 		$time = intval($time);
 		$now = time();
 
-
 		if (($now - $time) > $this->token_expiration) {
 			static::log('Token expiré');
 			return false;
@@ -292,10 +300,14 @@ class Identifier {
 			return false;
 		}
 
-		$this->champ = $champ;
-
 		static::debug("Token OK : formulaire $this->formulaire, champ $champ, identifiant $this->formulaire_identifiant");
 
 		return true;
 	}
+
+	public function generer_token_champ(string $champ): string {
+		include_spip('inc/securiser_action');
+		$time = time();
+		return $champ . ':' . $time . ':' . calculer_action_auteur("bigup/$this->formulaire/$this->formulaire_args/$champ/$time");
+	}
 }
